@@ -1,7 +1,6 @@
 from oarepo_model_builder.utils.deepmerge import deepmerge
 
 
-
 def alternative_gen(supported_langs, key):
     data = {}
     for lan in supported_langs:
@@ -16,18 +15,20 @@ def alternative_gen(supported_langs, key):
 
         if "text" in supported_langs[lan]:
             deepmerge(multilang_options, supported_langs[lan]["text"])
-
+        fields_dict = {}
         if "sort" in supported_langs[lan]:
             sort = deepmerge(
                 supported_langs[lan]["sort"], {"index": False, "language": lan}
             )
-            deepmerge(multilang_options, {"sort": sort})
+            deepmerge(fields_dict, {"sort": sort})
 
         if "keyword" in supported_langs[lan]:
             deepmerge(
-                multilang_options,
-                {"fields": {"keyword": supported_langs[lan]["keyword"]}},
+                fields_dict,
+                {"keyword": supported_langs[lan]["keyword"]},
             )
+        if fields_dict != {}:
+            deepmerge(multilang_options, {"fields": fields_dict})
         deepmerge(
             alt[key + "_" + lan].setdefault("mapping", {}),
             multilang_options,
